# -*- coding: utf-8 -*-
"""
Word2Vec
"""

__all__ = [
    "Word2VecAug",
    "BPEmbAug",
    "Thai2fitAug"
]

from thaitextaug.word2vec.word2vec import Word2VecAug
from thaitextaug.word2vec.BPEmb_core import BPEmbAug
from thaitextaug.word2vec.thai2fit import Thai2fitAug